@@ -25,26 +25,24 @@ class RemoveProjectMemberFromRoleRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'RemoveProjectMemberFromRole')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RoleCode(self):
+	def get_RoleCode(self): # String
 		return self.get_query_params().get('RoleCode')
 
-	def set_RoleCode(self,RoleCode):
-		self.add_query_param('RoleCode',RoleCode)
-
-	def get_ProjectId(self):
+	def set_RoleCode(self, RoleCode):  # String
+		self.add_query_param('RoleCode', RoleCode)
+	def get_ProjectId(self): # Long
 		return self.get_query_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_query_param('ProjectId',ProjectId)
-
-	def get_UserId(self):
+	def set_ProjectId(self, ProjectId):  # Long
+		self.add_query_param('ProjectId', ProjectId)
+	def get_UserId(self): # String
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
\ No newline at end of file
+	def set_UserId(self, UserId):  # String
+		self.add_query_param('UserId', UserId)
