@@ -23,52 +23,46 @@ from aliyunsdkdataworks_public.endpoint import endpoint_data
 class SearchMetaTablesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'SearchMetaTables','dide')
+		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'SearchMetaTables')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DataSourceType(self):
+	def get_DataSourceType(self): # String
 		return self.get_query_params().get('DataSourceType')
 
-	def set_DataSourceType(self,DataSourceType):
-		self.add_query_param('DataSourceType',DataSourceType)
-
-	def get_ClusterId(self):
+	def set_DataSourceType(self, DataSourceType):  # String
+		self.add_query_param('DataSourceType', DataSourceType)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_PageNumber(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_EntityType(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_EntityType(self): # Integer
 		return self.get_query_params().get('EntityType')
 
-	def set_EntityType(self,EntityType):
-		self.add_query_param('EntityType',EntityType)
-
-	def get_PageSize(self):
+	def set_EntityType(self, EntityType):  # Integer
+		self.add_query_param('EntityType', EntityType)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_AppGuid(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_AppGuid(self): # String
 		return self.get_query_params().get('AppGuid')
 
-	def set_AppGuid(self,AppGuid):
-		self.add_query_param('AppGuid',AppGuid)
-
-	def get_Keyword(self):
+	def set_AppGuid(self, AppGuid):  # String
+		self.add_query_param('AppGuid', AppGuid)
+	def get_Keyword(self): # String
 		return self.get_query_params().get('Keyword')
 
-	def set_Keyword(self,Keyword):
-		self.add_query_param('Keyword',Keyword)
\ No newline at end of file
+	def set_Keyword(self, Keyword):  # String
+		self.add_query_param('Keyword', Keyword)
